# file-utils

Contains a set of functions to help work with the files generated by the LMS
extractors. Does not contain any stand-alone scripts for execution.

For more information, and to see them in action, open the [filesystem-tutorial
notebook](../notebooks/filesystem-tutorial.ipynb)
